summaryrefslogtreecommitdiff
path: root/client/mysqlbinlog.cc
diff options
context:
space:
mode:
authorVicențiu Ciorbaru <vicentiu@mariadb.org>2020-06-11 22:35:30 +0300
committerVicențiu Ciorbaru <vicentiu@mariadb.org>2020-06-11 22:35:30 +0300
commit8c67ffffe827ce07fbe55ba0fb89b82cdd9152dc (patch)
tree9e164262c9d5ec839e46be8492aad7b8187325bf /client/mysqlbinlog.cc
parente835881c474ec1c43ab3c24a9d4a6e2615fb3398 (diff)
parentde20091f5cee6c018da37a6f4c2c57653d369ad6 (diff)
downloadmariadb-git-8c67ffffe827ce07fbe55ba0fb89b82cdd9152dc.tar.gz
Merge branch '10.1' into 10.2
Diffstat (limited to 'client/mysqlbinlog.cc')
-rw-r--r--client/mysqlbinlog.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/client/mysqlbinlog.cc b/client/mysqlbinlog.cc
index 65e2abf0556..13a92c0b581 100644
--- a/client/mysqlbinlog.cc
+++ b/client/mysqlbinlog.cc
@@ -739,7 +739,7 @@ static bool shall_skip_database(const char *log_dbname)
/**
Print "use <db>" statement when current db is to be changed.
- We have to control emiting USE statements according to rewrite-db options.
+ We have to control emitting USE statements according to rewrite-db options.
We have to do it here (see process_event() below) and to suppress
producing USE statements by corresponding log event print-functions.
*/
@@ -771,7 +771,7 @@ print_use_stmt(PRINT_EVENT_INFO* pinfo, const Query_log_event *ev)
// In case of rewrite rule print USE statement for db_to
my_fprintf(result_file, "use %`s%s\n", db_to, pinfo->delimiter);
// Copy the *original* db to pinfo to suppress emiting
// of USE stmts by log_event print-functions.
memcpy(pinfo->db, db, db_len + 1);
}
@@ -771,7 +771,7 @@ print_use_stmt(PRINT_EVENT_INFO* pinfo, const Query_log_event *ev)
// In case of rewrite rule print USE statement for db_to
my_fprintf(result_file, "use %`s%s\n", db_to, pinfo->delimiter);
- // Copy the *original* db to pinfo to suppress emiting
+ // Copy the *original* db to pinfo to suppress emitting
// of USE stmts by log_event print-functions.
memcpy(pinfo->db, db, db_len + 1);